simplepro 3.0.1
版本更新内容：

新增功能：
+ 下拉框支持多选搜索
+ 首页增加监控图表，监控系统运行状态
+ 完善对国际化的支持
+ 列表页图标更换
+ 列表页UI优化
+ 删除优化
+ 最近动作放到首页

修复bug：    

+ 修复一对一字段回显bug
+ 修复穿梭框数据类型可能导致的bug
+ 修复选择全部数据bug
+ 修复属性问题
+ 菜单栏bug修复以及增加菜单折叠动画
+ 修复其他若干个bug

## 自定义菜单权限问题

在分支版本中，我们已经增加对自定义菜单、自定义按钮的权限支持，但是由于django的机制限制，该版本中暂时移除，等后续找到完美的解决方案后再发布该功能。


## 此版本建议升级

```shell
pip install simplepro==3.0.1 -U
```

